@@ -12,7 +12,6 @@ from .cover_page_project import create_project_cover
 
 font_dir = Path('X:/9999_BID_AMS/AMS-VFB_Fonts')
 
-project_name = 'The South'
 logo = "X:/9999_BID_AMS/AMS_Logo's/RGB/Animotions_Logo_02_RGB.png"
 
 frame_width = 200
@@ -44,21 +43,19 @@ def main():
                  fname=font_dir.joinpath('Nexa Regular Italic.ttf'),
                  uni=True)
 
+    project_path = Path(get_cwd())
+
+    click.echo(f"🕵️‍♀️ We're running in {str(project_path)}")
+    project_name = input("🙏 Type in the project name: ")
+
     create_cover_page(pdf)
     create_project_cover(pdf, project_name)
 
-    # TODO remove hardcoded
-    #project_dir = 'X:/1652_BTN_ZUI'
-
-    project_path = Path(get_cwd())
-
     proj_number = str(project_path)[3:7]
 
     if len(proj_number) != 4:
         click.secho('probber')
 
-    print(proj_number)
-
     stills = project_path.joinpath('Test_Stills')
     if not stills.is_dir():
         click.secho(
