@@ -8,7 +8,7 @@ def create_cover_page(brief):
     brief.set_font('montserrat', size=48)
     brief.rect(x=10, y=10, w=275, h=190, style='F')
     #brief.set_xy(20, 100)
-    brief.image(cover_logo, x=20, y=100, width=50)
+    brief.image(cover_logo, x=20, y=90, w=100)
     #brief.cell(w=0, txt='ANIMOTIONS', ln=2)
     brief.set_xy(20, 110)
     brief.set_font('nexa', size=16)
